@@ -18,15 +18,13 @@
  * License along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
+#include <config.h>
 
-#include <pyglib.h>
 #include "pygoptiongroup.h"
 #include "pygi-error.h"
+#include "pygi-util.h"
 
-PYGLIB_DEFINE_TYPE("gi._glib.OptionGroup", PyGOptionGroup_Type, PyGOptionGroup)
+PYGLIB_DEFINE_TYPE("gi._gi.OptionGroup", PyGOptionGroup_Type, PyGOptionGroup)
 
 /**
  * pyg_option_group_new:
@@ -60,7 +58,7 @@ check_if_owned(PyGOptionGroup *self)
     if (self->other_owner)
     {
         PyErr_SetString(PyExc_ValueError, "The GOptionGroup was not created by "
-                        "gi._glib.OptionGroup(), so operation is not possible.");
+                        "gi._gi.OptionGroup(), so operation is not possible.");
         return TRUE;
     }
     return FALSE;
@@ -70,7 +68,7 @@ static void
 destroy_g_group(PyGOptionGroup *self)
 {
     PyGILState_STATE state;
-    state = pyglib_gil_state_ensure();
+    state = PyGILState_Ensure();
 
     self->group = NULL;
     Py_CLEAR(self->callback);
@@ -83,7 +81,7 @@ destroy_g_group(PyGOptionGroup *self)
         Py_DECREF(self);
     }
 
-    pyglib_gil_state_release(state);
+    PyGILState_Release(state);
 }
 
 static int
@@ -137,8 +135,7 @@ arg_func(const gchar *option_name,
     PyGILState_STATE state;
     gboolean no_error;
 
-    state = pyglib_gil_state_ensure();
-
+    state = PyGILState_Ensure();
     if (value == NULL)
         ret = PyObject_CallFunction(self->callback, "sOO",
                                     option_name, Py_None, self);
@@ -153,7 +150,7 @@ arg_func(const gchar *option_name,
     } else
 	no_error = pygi_gerror_exception_check(error) != -1;
 
-    pyglib_gil_state_release(state);
+    PyGILState_Release(state);
     return no_error;
 }
 
@@ -272,9 +269,9 @@ pyg_option_group_richcompare(PyObject *self, PyObject *other, int op)
 {
     if (Py_TYPE(self) == Py_TYPE(other) && 
           Py_TYPE(self) == &PyGOptionGroup_Type) {
-        return _pyglib_generic_ptr_richcompare(((PyGOptionGroup*)self)->group,
-                                               ((PyGOptionGroup*)other)->group,
-                                               op);
+        return pyg_ptr_richcompare(((PyGOptionGroup*)self)->group,
+                                   ((PyGOptionGroup*)other)->group,
+                                   op);
     } else {
         Py_INCREF(Py_NotImplemented);
         return Py_NotImplemented;
@@ -287,8 +284,11 @@ static PyMethodDef pyg_option_group_methods[] = {
     { NULL, NULL, 0 },
 };
 
-void
-pyglib_option_group_register_types(PyObject *d)
+/**
+ * Returns 0 on success, or -1 and sets an exception.
+ */
+int
+pygi_option_group_register_types(PyObject *d)
 {
     PyGOptionGroup_Type.tp_dealloc = (destructor)pyg_option_group_dealloc;
     PyGOptionGroup_Type.tp_richcompare = pyg_option_group_richcompare;
@@ -296,4 +296,6 @@ pyglib_option_group_register_types(PyObject *d)
     PyGOptionGroup_Type.tp_methods = pyg_option_group_methods;
     PyGOptionGroup_Type.tp_init = (initproc)pyg_option_group_init;
     PYGLIB_REGISTER_TYPE(d, PyGOptionGroup_Type, "OptionGroup");
+
+    return 0;
 }
