@@ -9,7 +9,7 @@ import pytest
 from gi.repository import GLib, GObject
 from gi._compat import PY3
 
-from . import testhelper
+import testhelper
 
 
 class PyGObject(GObject.GObject):
@@ -116,3 +116,16 @@ def test_to_unichar_conv():
 
     with pytest.raises(TypeError):
         testhelper.test_to_unichar_conv(u"AA")
+
+
+def test_constant_strip_prefix():
+    assert testhelper.constant_strip_prefix("foo", "bar") == "foo"
+    assert testhelper.constant_strip_prefix("foo", "f") == "oo"
+    assert testhelper.constant_strip_prefix("foo", "f") == "oo"
+    assert testhelper.constant_strip_prefix("ha2foo", "ha") == "a2foo"
+    assert testhelper.constant_strip_prefix("2foo", "ha") == "2foo"
+    assert testhelper.constant_strip_prefix("bla_foo", "bla") == "_foo"
+
+
+def test_state_ensure_release():
+    testhelper.test_state_ensure_release()
